# RawMaterialList

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**materials_data** | [**list[RawMaterial]**](RawMaterial.md) |  | [optional] 
**list_components** | [**list[RawMaterialListComponents]**](RawMaterialListComponents.md) |  | [optional] 
**options** | [**list[RawMaterialOptions]**](RawMaterialOptions.md) |  | [optional] 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


